@@ -13,7 +13,7 @@ use Hash::Util qw(lock_hashref);
 use Module::Load;
 use Types::Standard qw(InstanceOf HashRef);
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 plugin_keywords qw(validate_form validate errors validator_language);
 
@@ -70,6 +70,8 @@ sub validate_form {
     my ($self, $form) = @_;
 
     if (my $validator_profile = $self->config_obj->form($form)) {
+        autoload $validator_profile;
+
         my $input  = $self->dsl->body_parameters->as_hashref_mixed;
         my $result = $self->validate($input, $validator_profile->new);
 
@@ -167,12 +169,11 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
     use Dancer2::Plugin::FormValidator;
-    use App::Http::Validators::Form;
 
     post '/form' => sub {
         if (my $valid_hash_ref = validate_form 'form') {
@@ -267,7 +268,6 @@ Then you need to set an form => validator association in config:
 Now you can validate POST parameters in your controller:
 
     use Dancer2::Plugin::FormValidator;
-    use App::Http::Validators::RegisterForm;
 
     post '/register' => sub {
         if (my $valid_hash_ref = validate_form 'register_form') {
@@ -364,6 +364,8 @@ Template app/register:
 
     my $valid_hash_ref = validate_form $form
 
+Returns $valid_hash_ref if validation succeed, otherwise rerurns undef.
+
 =head3 validator_language
 
     validator_language $lang
@@ -400,25 +402,34 @@ Template app/register:
 
 =head3 required
 
+Validate that field exists and not empty string.
+
 =head3 same
 
 =head1 TODO
 
 =over 4
 
-=item Configuration details: list all fields and describe them.
+=item *
+Configuration details: list all fields and describe them.
 
-=item Document with example and descriptions DSL's.
+=item *
+Document with example and descriptions DSL's.
 
-=item Document with example all validators.
+=item *
+Document with example all validators.
 
-=item Document all config field with explanation.
+=item *
+Document all config field with explanation.
 
-=item Document all Roles and HashRef structures.
+=item *
+Document all Roles and HashRef structures.
 
-=item Extensions docs.
+=item *
+Extensions docs.
 
-=item Contribution and help details.
+=item *
+Contribution and help details.
 
 =back
 
